@@ -1,15 +1,14 @@
 /** ===========================================================
  * @file
  *
- * This file is a part of kipi-plugins project
- * <a href="http://www.digikam.org">http://www.digikam.org</a>
+ * This file is a part of KDE project
  *
  * Date        : 2009-13-11
  * Description : Helper functions for writing images
  *
  * Copyright (C) 1994-1996 by Thomas G. Lane.
  * Copyright (C) 2009-2010 by Patrick Spendrin <ps_ml@gmx.de>
- * Copyright (C) 2007-2017 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2007-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This file is based on jdatadst.c from libjpeg.
  *
@@ -118,7 +117,7 @@ void term_destination (j_compress_ptr cinfo)
     /* Write any data remaining in the buffer */
     if (datacount > 0)
     {
-        if (dest->outDevice->write((char*)dest->buffer, datacount) != (ssize_t) datacount)
+        if ((size_t)dest->outDevice->write((char*)dest->buffer, datacount) != (size_t)datacount)
             ERREXIT(cinfo, JERR_FILE_WRITE);
     }
 }
